@@ -3,7 +3,7 @@
 
     SPDX-FileCopyrightText: 2006 Kevin Ottens <ervin@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-only
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "kcompositejob.h"
@@ -74,7 +74,7 @@ const QList<KJob *> &KCompositeJob::subjobs() const
 void KCompositeJob::clearSubjobs()
 {
     Q_D(KCompositeJob);
-    for (KJob *job : qAsConst(d->subjobs)) {
+    for (KJob *job : std::as_const(d->subjobs)) {
         job->setParent(nullptr);
         disconnect(job, &KJob::result, this, &KCompositeJob::slotResult);
         disconnect(job, &KJob::infoMessage, this, &KCompositeJob::slotInfoMessage);
